@@ -149,6 +149,7 @@ class MountebankServer:
             post = requests.post(self.server_url, json=json, timeout=10)
             post.raise_for_status()
             definition.port = post.json()["port"]
+            definition.host = self.host
             self.running_imposters_by_port[cast(int, definition.port)] = definition
 
     def delete_imposters(self) -> None:
@@ -174,6 +175,12 @@ class MountebankServer:
     def imposter_url(self, imposter_port: int) -> furl:
         return self.server_url.add(path=str(imposter_port))
 
+    def query_all_impostors(self):
+        server_info = requests.get(self.server_url)
+        imposters = server_info.json()["imposters"]
+        for imposter in imposters:
+            yield Imposter.from_structure(requests.get(imposter["_links"]["self"]["href"]).json())
+
 
 class ExecutingMountebankServer(MountebankServer):
     """A Mountebank mock server, running one or more impostors, one for each domain being mocked.
